@@ -54,7 +54,7 @@
 ##' @seealso This function is called internally by \code{\link{generateRasters}}.
 ##'
 ##' @examples
-##' \dontrun{
+##' \donttest{
 ##' # Find example rasters
 ##' rasterFiles <- list.files(system.file('extdata', package='envirem'), full.names=TRUE)
 ##'
@@ -65,7 +65,7 @@
 ##' solar <- stack(solradFiles)
 ##' 
 ##' # generate all possible envirem variables
-##' layerCreation(worldclim, solar, var='all')
+##' layerCreation(worldclim, solar, var='all', tempScale = 10)
 ##' }
 ##' @export
 
@@ -134,6 +134,19 @@ layerCreation <- function(masterstack, solradstack, var, tempScale = 1) {
 	tminstack <- tminstack / tempScale
 	tmaxstack <- tmaxstack / tempScale
 	
+	# bioclim 1,2,4,5,6,7,8,9,10,11 are affected by tempScale
+	masterstack[[grep('bio_1$', names(masterstack))]] <- masterstack[[grep('bio_1$', names(masterstack))]] / tempScale
+	masterstack[[grep('bio_2$', names(masterstack))]] <- masterstack[[grep('bio_2$', names(masterstack))]] / tempScale
+	masterstack[[grep('bio_4$', names(masterstack))]] <- masterstack[[grep('bio_4$', names(masterstack))]] / tempScale
+	masterstack[[grep('bio_5$', names(masterstack))]] <- masterstack[[grep('bio_5$', names(masterstack))]] / tempScale
+	masterstack[[grep('bio_6$', names(masterstack))]] <- masterstack[[grep('bio_6$', names(masterstack))]] / tempScale
+	masterstack[[grep('bio_7$', names(masterstack))]] <- masterstack[[grep('bio_7$', names(masterstack))]] / tempScale
+	masterstack[[grep('bio_8$', names(masterstack))]] <- masterstack[[grep('bio_8$', names(masterstack))]] / tempScale
+	masterstack[[grep('bio_9$', names(masterstack))]] <- masterstack[[grep('bio_9$', names(masterstack))]] / tempScale
+	masterstack[[grep('bio_10$', names(masterstack))]] <- masterstack[[grep('bio_10$', names(masterstack))]] / tempScale
+	masterstack[[grep('bio_11$', names(masterstack))]] <- masterstack[[grep('bio_11$', names(masterstack))]] / tempScale
+	
+	
 	# if tmean not already present in stack, then calculate it from tmin and tmax
 	if (!any(grepl('tmean', names(masterstack)))) {
 		cat('\t\t...calculating mean temp...\n')
@@ -247,6 +260,17 @@ layerCreation <- function(masterstack, solradstack, var, tempScale = 1) {
 		reslist[['aridityIndexThornthwaite']] <- aridIndThorn
 	}
 
+	# if minTempWarmest or maxTempColdest were requested, put them back on the same
+	# scale as the input temperature rasters
+	if ('minTempWarmest' %in% var) {
+		reslist[['minTempWarmest']] <- reslist[['minTempWarmest']] * tempScale
+	}
+
+	if ('maxTempColdest' %in% var) {
+		reslist[['maxTempColdest']] <- reslist[['maxTempColdest']] * tempScale
+	}
+
+
 	reslist <- raster::stack(reslist)
 	return(reslist)
 }
